==> openwebbeans-1.7.6-source-release.zip: openwebbeans-1.7.6/webbeans-impl/src/test/java/org/apache/webbeans/test/disposes/beans/RequestModelProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.disposes.beans;

import javax.enterprise.context.RequestScoped;
import javax.enterprise.context.ApplicationScoped;
import javax.enterprise.inject.Disposes;
import javax.enterprise.inject.Produces;
import javax.inject.Inject;
import javax.inject.Named;

import org.apache.webbeans.test.disposes.common.DependentModel;
import org.apache.webbeans.test.disposes.common.HttpHeader;
import org.apache.webbeans.test.disposes.common.RequestModel;

@ApplicationScoped
@Named("org.apache.webbeans.test.disposes.beans.RequestBean")
public class RequestModelProducer {

    @Inject @HttpHeader
    private DependentModel dependentModel;

    public static boolean producerGotDestroyed = false;

    @Produces @RequestScoped @Named("rproduce")
    public RequestModel rproduce()
    {
        RequestModel rmodel =  new RequestModel();
        rmodel.setDisposeModel(dependentModel);

        System.out.println("produced RequestModel=" + rmodel);
        return rmodel;
    }
    
    public void rdispose(@Disposes RequestModel rmodel)
    {
        producerGotDestroyed = true;
    }    
}

==> openwebbeans-4.0.3-source-release.zip: openwebbeans-4.0.3/webbeans-impl/src/test/java/org/apache/webbeans/test/disposes/beans/RequestModelProducer.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.webbeans.test.disposes.beans;

import jakarta.enterprise.context.RequestScoped;
import jakarta.enterprise.context.ApplicationScoped;
import jakarta.enterprise.inject.Disposes;
import jakarta.enterprise.inject.Produces;
import jakarta.inject.Inject;
import jakarta.inject.Named;

import org.apache.webbeans.test.disposes.common.DependentModel;
import org.apache.webbeans.test.disposes.common.HttpHeader;
import org.apache.webbeans.test.disposes.common.RequestModel;

@ApplicationScoped
@Named("org.apache.webbeans.test.disposes.beans.RequestBean")
public class RequestModelProducer {

    @Inject @HttpHeader
    private DependentModel dependentModel;

    public static boolean producerGotDestroyed = false;

    @Produces @RequestScoped @Named("rproduce")
    public RequestModel rproduce()
    {
        RequestModel rmodel =  new RequestModel();
        rmodel.setDisposeModel(dependentModel);

        System.out.println("produced RequestModel=" + rmodel);
        return rmodel;
    }
    
    public void rdispose(@Disposes RequestModel rmodel)
    {
        producerGotDestroyed = true;
    }    
}
